@@ -23,7 +23,7 @@
 ## length of 5 which is sort of ad-hoc.
 
 LABELS <-
-function(x, max_width = NULL, dots = "...", unique = FALSE, limit = NULL)
+function(x, max_width = NULL, dots = "...", unique = FALSE, limit = NULL, ...)
 {
     x <- as.list(x)
     l <- length(x)
@@ -40,7 +40,7 @@ function(x, max_width = NULL, dots = "...", unique = FALSE, limit = NULL)
     ## create a label for components without given one
     empty <- ret == ""
     if (any(empty))
-        ret[empty] <- sapply(x[empty], LABEL, limit)
+        ret[empty] <- sapply(x[empty], LABEL, limit, ...)
 
     ## check maximum width (max_width == NULL => unbounded)
     if (!is.null(max_width)) {
@@ -61,49 +61,61 @@ function(x, max_width = NULL, dots = "...", unique = FALSE, limit = NULL)
 }
 
 LABEL <-
-function(x, limit = NULL)
+function(x, limit = NULL, ...)
     UseMethod("LABEL")
 
 LABEL.default <-
-function(x, limit = NULL)
+function(x, limit = NULL, ...)
     paste("<<", class(x)[1L], ">>", sep = "")
 
 LABEL.matrix <-
-function(x, limit = NULL)
+function(x, limit = NULL, ...)
     sprintf("<<%ix%i matrix>>", nrow(x), ncol(x))
 
 LABEL.numeric <-
 LABEL.factor <-
-LABEL.character <-
 LABEL.integer <-
 LABEL.logical <-
-function(x, limit = NULL) {
+function(x, limit = NULL, ...) {
     if (is.null(limit))
         limit <- 2L
-    .format_or_class(x, limit)
+    .format_or_class(x, limit, ...)
+}
+
+LABEL.character <-
+function(x, limit = NULL, quote = FALSE, ...) {
+    if (is.null(limit))
+        limit <- 2L
+    if (quote)
+        x <- paste("\"", x, "\"", sep = "")
+    .format_or_class(x, limit, ...)
 }
 
 LABEL.list <-
-function(x, limit = NULL ) {
+function(x, limit = NULL, ...) {
     if (is.null(limit))
         limit <- 1L
-    .format_or_class(x, limit)
+    .format_or_class(x, limit, ...)
 }
 
 LABEL.set <-
 LABEL.gset <-
 LABEL.tuple <-
-function(x, limit = NULL) {
+function(x, limit = NULL, ...) {
     if (is.null(limit))
         limit <- 6L
-    .format_or_class(x, limit)
+    .format_or_class(x, limit, ...)
 }
 
 .format_or_class <-
-function(x, limit)
+function(x, limit, ...)
 {
-    if (length(unclass(x)) < limit)
-        format(x)
-    else
-        paste("<<", class(x)[1L], "(", length(unclass(x)), ")>>", sep = "")
+    l <- length(as.list(x))
+    if (l < limit) {
+        if (is.integer(x))
+            format(paste(x, "L", sep = ""), ...)
+        else
+            format(x, ...)
+    } else
+        paste("<<", class(x)[1L], "(", l, ")>>", sep = "")
 }
